/*
 * @Author: zc
 * @description 数据统计-中心统计
 */
import request from '@/utils/request';
import qs from "qs";
/**
 * @description 中心报表统计
 * @param {object} params
 */
export const centerReport = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/center_report_forms_statistics`,
    method: 'get',
    params,
  });
}
/**
 * @description 高频来电统计
 * @param {object} params
 */
export const departmentHighFrequency = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/high_frequency_call_statistics`,
    method: 'get',
    params,
  });
}
/**
 * @description 高频来电统计详情
 * @param {object} params
 */
export const departmentHighFrequencyDetail = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/high_frequency_call_statistics_order_list`,
    method: 'get',
    params,
  });
}
/**
 * @description 高频事件统计
 * @param {object} params
 */
export const departmentHighFrequencyEvent = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/highmatter-warning`,
    method: 'get',
    params,
  });
}
/**
 * @description 高频事件统计明细
 * @param {object} params
 */
export const departmentHighFrequencyEventDetail = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/highmatter-warning-detail`,
    method: 'get',
    params,
    paramsSerializer: (params:any) => qs.stringify(params)
  });
}
/**
 * @description 市州互转-转入
 * @param {object} params
 */
export const cityConversionIn = (params: object) => {
  return request({
    url: `/api/v1/TranspondCity/order_receive_in_list`,
    method: 'get',
    params,
  });
}
/**
 * @description 市州互转-转出
 * @param {object} params
 */
export const cityConversionOut = (params: object) => {
  return request({
    url: `/api/v1/TranspondCity/order_transfer_out_list`,
    method: 'get',
    params,
  });
}
/**
 * @description 回退错件统计
 * @param {object} params
 */
export const centerReturnError = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact`,
    method: 'get',
    params,
  });
}
/**
 * @description 回退错件统计导出
 * @param {object} data
 */
export const centerReturnErrorExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact/_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 回退错件统计明细
 * @param {object} params
 */
export const centerReturnErrorDetail = (params: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact_detail`,
    method: 'get',
    params,
  });
}
/**
 * @description 回退错件统计明细导出
 * @param {object} data
 */
export const centerReturnErrorDetailExport = (data: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact_detail/_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 回退错件统计明细基础信息
 * @param {object} params
 */
export const centerReturnErrorDetailBase = (params?: object) => {
  return request({
    url: `/api/v1/BiOrder/reTransact_base`,
    method: 'get',
    params,
  });
}
/**
 * @description 应急清单
 * @param {object} params
 */
export const centerEmergencyList = (params: object) => {
  return request({
    url: `/api/v1/ContingencyManagement/getlist`,
    method: 'get',
    params,
  });
}
/**
 * @description 应急清单导出
 * @param {object} data
 */
export const centerEmergencyListExport = (data: object) => {
  return request({
    url: `/api/v1/ContingencyManagement/getlist_export`,
    method: 'post',
    data,
    responseType: 'blob',
  }, {
    reduce_data_format: false
  });
}
/**
 * @description 新增分析报告
 * @param {object} data
 */
export const centerAddAnalysisReport = (data: object) => {
  return request({
    url: `/api/v1/Order/analysis`,
    method: 'post',
    data,
  });
}
/**
 * @description 删除分析报告
 * @param {object} data
 */
export const centerDeleteAnalysisReport = (data: object) => {
  return request({
    url: `/api/v1/Order/analysis`,
    method: 'delete',
    data,
  });
}
/**
 * @description 分析报告列表
 * @param {object} params
 */
export const centerAnalysisReportList = (params: object) => {
  return request({
    url: `/api/v1/Order/analysis_list`,
    method: 'get',
    params,
  });
}
/**
 * @description 分析报告明细
 * @param {object} params
 */
export const centerAnalysisReportDetail = (params: object) => {
  return request({
    url: `/api/v1/Order/analysis_detail`,
    method: 'get',
    params,
  });
}
/**
 * @description 生成分析报告
 * @param {object} params
 */
export const centerGenerateAnalysisReport = (params: object) => {
  return request({
    url: `/api/v1/Order/analysis_report`,
    method: 'get',
    params,
  });
}